@@ -12,11 +12,10 @@
 #' @noRd
 #'
 .cleanArgs <- function(args, func = NULL) {
-
   if (is.null(func)) stop("You must supply a reference function")
-  
-  form <- names(formals(files2SpectraObject))
-  refForm <- names(formals(func))
+
+  f2SOformals <- names(formals(files2SpectraObject))
+  funcFormals <- names(formals(func))
 
   # Basic procedure is to
   #   1. Remove the files2SpectraObject arguments
@@ -27,22 +26,26 @@
   #      manually in files2SpectraObject)
 
   # Step 1
-  args[form] <- NULL
-  
+  args[f2SOformals] <- NULL
+
   # Step 2
-  keep <- names(args) %in% refForm
-  args[!keep] <- NULL
-  
-  # Step 3 
-  
+  keep <- names(args) %in% funcFormals
+  args[!keep] <- NULL # remove any remaining arguments
+
+  # Step 3
+
   if (func == "read.table") {
-  	if ("file" %in% names(args)) args$file <- NULL
+    if ("file" %in% names(args)) args$file <- NULL
   }
-  
+
+  if (func == "readJDX") {
+    if ("file" %in% names(args)) args$file <- NULL
+  }
+
   if (func == "list.files") {
-  	if ("pattern" %in% names(args)) args$pattern <- NULL
-  	if ("full.names" %in% names(args)) args$full.names <- NULL
+    if ("pattern" %in% names(args)) args$pattern <- NULL
+    if ("full.names" %in% names(args)) args$full.names <- NULL
   }
-  
+
   return(args)
-}	
+}
